@@ -1109,8 +1109,12 @@ def SignalSubset(sig_data,freq,fields, **kwargs):
     Returns
     -------
     out : dict
-        Dictionary with the objects/places passed in the input, inside each one will have the channels
-        passed with the subset of the data.
+        if fields = None:
+            return a dictionary with size equal to the list in start_time or end_time lenght, with others
+            dictionaries with the subset in each channel.
+        else:
+            Dictionary with the objects/places passed in the input, inside each one will have the channels
+            passed with the subset of the data.
 
     See Also
     --------
@@ -1136,17 +1140,14 @@ def SignalSubset(sig_data,freq,fields, **kwargs):
             cortes = {}
             for ç,canal in enumerate(sig_data.columns):
                 if type(start_time) == type(None):
-                    for i in range(len(end_time)):
-                        cortes[ç] = sig_data[canal][None:end_time[i]*freq]
-                        dicts[j] = cortes 
+                    cortes[ç] = sig_data[canal][None:end_time[j]*freq]
+                    dicts[j] = cortes 
                 elif type(end_time) == type(None):
-                    for i in range(len(start_time)):
-                        cortes[ç] = sig_data[canal][start_time[i]*freq:None]
-                        dicts[j] = cortes 
+                    cortes[ç] = sig_data[canal][start_time[j]*freq:None]
+                    dicts[j] = cortes 
                 else: 
-                    for i in range(len(start_time)):
-                        cortes[ç] = sig_data[canal][start_time[i]*freq:end_time[i]*freq]
-                        dicts[j] = cortes 
+                    cortes[ç] = sig_data[canal][start_time[j]*freq:end_time[j]*freq]
+                    dicts[j] = cortes
 
     else:
         lista = []
@@ -1171,6 +1172,7 @@ def SignalSubset(sig_data,freq,fields, **kwargs):
 
     return dicts
 
+
 def LFP(data):
     """
     Performs LFP data extraction from a MATLAB file (.mat) and returns all channels arranged in 
@@ -1179,7 +1181,7 @@ def LFP(data):
     Parameters
     ----------
     data : .mat
-        Plexon data in .mat format
+        Plexon data in .mat format.
        
     Returns
     -------
